// Basic New-Keynesian Model
// Computational Course, Dynare Example
// Brent Bundick

var n, pie, rr, a, y, c, w, mu, r;

varexo ea;

parameters beta, phip, frischlselasticity, chi, eta, thetamu, fixedcost, 
		piess, rss, rrss, phipie, phix, rhoa, vola, 
		yss, nss, ass, muss, css, wss;


// Structural Parameters

beta = 0.99;
phip = 160;
frischlselasticity = 1.0;
eta = 1/frischlselasticity;
thetamu = 6.0;

// Steady-State Normalizations & Parameter Implications

yss = 1.0;
ass = 1.0;
muss = thetamu/(thetamu - 1);
css = yss;
wss = (muss)^(-1);
fixedcost = (muss - 1)*yss;
nss = yss + fixedcost;
chi = wss*css^(-1)*nss^(-eta);

// Monetary Policy Parameters

piess = 1.00;
rss = piess/beta;
rrss = piess/beta;
phipie = 2.0;
phix = 0.5;

// Stochastic Processes

rhoa = 0.90;
vola = 0.005;

// Model Equations

model;

y + fixedcost = n; 								// Aggregate production function
w = chi*c*(n^eta); 								// Labor supply
w = 1/mu; 										// Labor demand

1 = r*beta*(a(+1)/a)*(c/c(+1))*(pie(+1))^(-1); 		// Nominal Bond Euler equation
1 = rr*beta*(a(+1)/a)*(c/c(+1)); 					// Real Bond Euler equation
y = c + (phip/2)*(pie/piess-1)^2*y; 				// National accounts identity


log(r) = log(rss) + phipie*log(pie/piess) + phix*log(y/yss); 	// Taylor-type rule
phip*(pie/piess-1)*(pie/piess) = (1-thetamu) + thetamu/mu + 
				beta*(a(+1)/a)*(c/c(+1))*phip*(pie(+1)/piess-1)*(y(+1)/y)*(pie(+1)/piess); 	// NKPC
a = rhoa*a(-1) + (1-rhoa)*ass + vola*ea; 														// Preference shock evolution
end;

// Steady state values come from above parameters


initval;
a = ass;
n = nss;
pie = piess;
rr = rrss;
y = yss;
c = css;
w = wss;
mu = muss;
r = rss;
end;
steady;

check;

shocks;
var ea = 1;
end;

stoch_simul(order=1,periods=10000,irf=20) y, pie, r, rr;
